
local physics = require( "physics" )
local composer = require( "composer" )

local scene = composer.newScene()

-- -----------------------------------------------------------------------------------
-- Code outside of the scene event functions below will only be executed ONCE unless
-- the scene is removed entirely (not recycled) via "composer.removeScene()"
-- -----------------------------------------------------------------------------------




-- -----------------------------------------------------------------------------------
-- Scene event functions
-- -----------------------------------------------------------------------------------
function scene:resumeGame(wantExit)
  if wantExit == true then
    --exit game
      composer.gotoScene( "menu" )
  else
    --resume game
    physics.start()
    transition:resume()
  end
end

-- create()
function scene:create( event )

	local sceneGroup = self.view
	-- Code here runs when the scene is first created but has not yet appeared on screen
  
  physics.start(0,0)
  physics.setGravity(0,1)
  physics.setDrawMode( "hybrid" )

  local bigRect = display.newLine( sceneGroup, 0, 480, 320, 480)
  physics.addBody(bigRect, "static")
  
  local ball = display.newCircle( sceneGroup, 50, 0, 10)
  physics.addBody(ball, "dynamic", {bounce=1, radius=10})  
  ball:setLinearVelocity(0, 20)

end


-- show()
function scene:show( event )

	local sceneGroup = self.view
	local phase = event.phase

	if ( phase == "will" ) then
		-- Code here runs when the scene is still off screen (but is about to come on screen)

	elseif ( phase == "did" ) then
		-- Code here runs when the scene is entirely on screen

	end
end


-- hide()
function scene:hide( event )

	local sceneGroup = self.view
	local phase = event.phase

	if ( phase == "will" ) then
		-- Code here runs when the scene is on screen (but is about to go off screen)
    Runtime:removeEventListener(tapListener)
    display:remove(sceneGroup)

    transition:pause()
    physics.pause()
    
    local result = physics.stop()
    if result == false then
      print("Wait a moment...")
      timer.performWithDelay( 2000, function() physics.stop() end)
    end

	elseif ( phase == "did" ) then
		-- Code here runs immediately after the scene goes entirely off screen
    composer.removeScene("parent")
	end
end

-- destroy()
function scene:destroy( event )

	local sceneGroup = self.view
	-- Code here runs prior to the removal of scene's view

end

function tapListener ( event )
  if ( event.numTaps == 2 ) then
    physics.pause()

    composer.showOverlay( "pause_resume", {isModal=true} )
  end
end

-- -----------------------------------------------------------------------------------
-- Scene event function listeners
-- -----------------------------------------------------------------------------------
scene:addEventListener( "create", scene )
scene:addEventListener( "show", scene )
scene:addEventListener( "hide", scene )
scene:addEventListener( "destroy", scene )
-- -----------------------------------------------------------------------------------
Runtime:addEventListener( "tap", tapListener )

return scene
